"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleConsoleWarnings = exports.sanitizeHTMLTags = exports.updateLinkedPhrase = exports.defineOptions = exports.validHTMLtagRegExp = void 0;
;
// DEFAULTS
exports.validHTMLtagRegExp = /<(“[^”]*”|'[^’]*’|[^'”>])*>/;
var defaultWarnings = false;
var defaultTarget = '_blank';
var defaultUrlRegExp = new RegExp(['^(https?:\/\/(?:www\.|(?!www))[a-zA-Z0-9][a-zA-Z0-9-]+[a-zA-Z0-9]\.',
    '[^\s]{2,}|www\.[a-zA-Z0-9][a-zA-Z0-9-]+[a-zA-Z0-9]\.',
    '[^\s]{2,}|https?:\/\/(?:www\.|(?!www))[a-zA-Z0-9]+\.',
    '[^\s]{2,}|www\.[a-zA-Z0-9]+\.[^\s]{2,})$'].join(''));
// HELPERS
function defineOptions(options) {
    var urlRegEx = options.urlRegEx ? options.urlRegEx : defaultUrlRegExp;
    var target = options.target ? options.target : defaultTarget;
    var disableWarnings = options.disableWarnings ? options.disableWarnings : defaultWarnings;
    return { urlRegEx: urlRegEx, target: target, disableWarnings: disableWarnings };
}
exports.defineOptions = defineOptions;
;
function updateLinkedPhrase(nEnd, linkedPhrase, newText) {
    if (nEnd) {
        return linkedPhrase + newText + '\n';
    }
    return linkedPhrase + newText;
}
exports.updateLinkedPhrase = updateLinkedPhrase;
function sanitizeHTMLTags(text) {
    var letterArr = Array.from(text);
    var replaced = letterArr.map(function (letter) {
        return letter === '<' ? '&lt;' : letter;
    });
    return replaced.join('');
}
exports.sanitizeHTMLTags = sanitizeHTMLTags;
function handleConsoleWarnings(vnode, argText, disableWarnings) {
    if (disableWarnings) {
        return false;
    }
    var stopExec = false;
    if (!argText) {
        console.error("v-dolinks: seems like v-dolinks directive argument is empty (inside of <".concat(vnode.tag, "> tag)."), 'Pass text directly to v-dolniks as argument: v-dolinks="\'Your text here\'"');
        stopExec = true;
    }
    if (vnode.children && vnode.children[0].text) {
        console.warn("v-dolinks: text inside of <".concat(vnode.tag, "> is ignored"));
    }
    return stopExec;
}
exports.handleConsoleWarnings = handleConsoleWarnings;
